@@ -60,5 +60,7 @@ class BreadcrumbMiddleware(BaseDebugMiddleware):
                 )
             if full_query.get("variables"):
                 self.logger(
-                    category="graphql", message=full_query["variables"], level="info"
-                )
\ No newline at end of file
+                    category="graphql",
+                    message=json.dumps(full_query["variables"]),
+                    level="info",
+                )
